@@ -61,6 +61,7 @@ public:
         EdrPolicyRole,
         BitsPerColorOptionsPreferEfficiencyRole,
         BitsPerColorOptionsPreferAccuracyRole,
+        SharpnessRole,
     };
     Q_ENUM(OutputRoles)
 
@@ -168,6 +169,9 @@ private:
 
     QVariantList replicasModel(const KScreen::OutputPtr &output) const;
 
+    bool shouldShowSerialNumber(const KScreen::OutputPtr &output) const;
+    bool shouldShowConnector(const KScreen::OutputPtr &output) const;
+
     QList<Output> m_outputs;
 
     ConfigHandler *const m_config;
